from datetime import datetime
import time
import serial
import openpyxl


# Charger la feuille Excel
workbook = openpyxl.load_workbook("C:/Users/Imad/Dropbox/inventory.xlsx")
sheet = workbook.active

# Définir les entêtes si la feuille est vide
if sheet.max_row == 0:
    sheet.append(['Date', 'Time', 'RFID_UID', 'Nom item', 'Nombre article', 'Position de l\'article'])
    workbook.save("C:/Users/Imad/Dropbox/Inventory.xlsx")

scanned_uids = set()  # Ensemble pour stocker les UID des cartes scannées

def ajouter_dans_excel(rfid_uid, nom_item, nombre_article, position_article):
    """
    Ajoute les données dans la feuille Excel.

    Args:
        rfid_uid (str): UID de la carte RFID.
        nom_item (str): Nom de l'item.
        nombre_article (int): Nombre d'articles.
        position_article (str): Position de l'article (Étagère).
    """
    date_time = datetime.now().strftime("%Y-%m-%d %H:%M:%S")

    # Initialiser la nouvelle ligne
    nouvelle_ligne = [date_time.split()[0], date_time.split()[1], rfid_uid, nom_item, nombre_article, position_article]

    # Ajouter la nouvelle ligne dans la feuille Excel
    sheet.append(nouvelle_ligne)

    # Sauvegarder les modifications dans le fichier Excel
    workbook.save("C:/Users/Imad/Dropbox/Inventory.xlsx")

def saisir_informations():
    """
    Permet au client de saisir les informations.
    """
    nom_item = input("Nom de l'item : ")
    nombre_article = int(input("Nombre d'article: "))  # Par défaut, ajoutez un article
    position_article = input("Position de l'article (Étagère) : ")

    return nom_item, nombre_article, position_article

# Ouvrir le port série
ser = serial.Serial('COM5', 9600)

def essai():
    start_time = time.time()  # Enregistrez le temps de début

    try:
        while True:
            data = ser.readline().decode().strip()
            if data.startswith("UID de la carte :"):
                rfid_uid = data.split(":")[1].strip()
                if rfid_uid not in scanned_uids:
                    # Demander au client de saisir les informations
                    nom_item, nombre_article, position_article = saisir_informations()
                    scanned_uids.add(rfid_uid)
                    start_time = time.time()  # Réinitialiser le temps de début après la saisie des informations
                    ajouter_dans_excel(rfid_uid, nom_item, nombre_article, position_article)

                else:
                    # Vérifier si le scan a duré plus de 3 secondes
                    if time.time()> 1 :
                        print("Modifier la base de données.")
                        nombre_article_a_retirer = float(input("Combien d'article voulez-vous retirer?(nombre negatif) : "))
                        nombre_article_a_ajouter = int(input("Combien d'article voulez-vous ajouter? : "))
                        nombre_article+= nombre_article_a_retirer
                        nombre_article+= nombre_article_a_ajouter
                    return rfid_uid, nom_item, nombre_article, position_article

 

    except serial.SerialException as se:
        print(f"Erreur d'ouverture du port série : {se}")
    except Exception as e:
        print(f"Erreur : {e}")
    finally:
        # Fermer le port série
        ser.close()
# Appeler la fonction essai
rfid_uid, nom_item, nombre_article, position_article = essai()
ajouter_dans_excel(rfid_uid, nom_item, nombre_article, position_article)



